@@ -15,7 +15,7 @@ test_that("Result with default parameters is tbl_df with required columns",{
 
   fit = stan_fit(data, iter = 300, chains = 1)
   class(fit) = class(fit)[-1] # Remove class breathteststanfit
-  cf = coef_by_group(fit) # S3 method
+  cf = breathtestcore::coef_by_group(fit) # S3 method
   expect_is(cf, "tbl_df")
   expect_is(cf, "coef_by_group")
   expect_identical(ncol(cf), 7L)
